#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
from .class_name import prepare_class_name
from .create import create_type, create_dataclass
from .create_function import create_function, Missing

# backward compatibility
from frozendict import frozendict as HashableDict
